module Mi exposing (TokenData, expectJson, request, tokenDecoder)

import Http
import Json.Decode as D


type alias TokenData =
    { sub : String
    , jti : String
    }


tokenDecoder : D.Decoder TokenData
tokenDecoder =
    D.map2 TokenData
        (D.field "sub" D.string)
        (D.field "jti" D.string)


request method token path body expect =
    Http.request
        { method = method
        , body = body
        , headers =
            [ Http.header "Authorization" token
            ]
        , url = path
        , expect = expect
        , timeout = Nothing
        , tracker = Nothing
        }


expectJson : (Result Http.Error a -> msg) -> D.Decoder a -> Http.Expect msg
expectJson toMsg decoder =
    Http.expectStringResponse toMsg <|
        \response ->
            case response of
                Http.BadUrl_ url ->
                    Err (Http.BadUrl url)

                Http.Timeout_ ->
                    Err Http.Timeout

                Http.NetworkError_ ->
                    Err Http.NetworkError

                Http.BadStatus_ metadata body ->
                    Err (Http.BadStatus metadata.statusCode)

                Http.GoodStatus_ metadata body ->
                    case D.decodeString decoder body of
                        Ok value ->
                            Ok value

                        Err err ->
                            Err (Http.BadBody (D.errorToString err))
